@@ -37,7 +37,7 @@ use IO::Socket::INET;
 use Path::Class;
 use namespace::autoclean;
 
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 $VERSION = eval $VERSION;
 
 has 'directory' => (
@@ -156,7 +156,7 @@ sub ref_names {
         foreach my $line ( $packed_refs->slurp( chomp => 1 ) ) {
             next if $line =~ /^#/;
             next if $line =~ /^\^/;
-            my ( $sha1, my $name ) = split ' ', $line;
+            my ( $sha1, $name ) = split ' ', $line;
             push @names, $name;
         }
     }
@@ -202,7 +202,7 @@ sub ref_sha1 {
         my $last_sha1;
         foreach my $line ( $packed_refs->slurp( chomp => 1 ) ) {
             next if $line =~ /^#/;
-            my ( $sha1, my $name ) = split ' ', $line;
+            my ( $sha1, $name ) = split ' ', $line;
             $sha1 =~ s/^\^//;
             $name ||= $last_name;
 
